@@ -103,14 +103,14 @@ def _param_invariant_exception(param_name, desc):
 
 
 def failed(desc):
-    if not _is_str(desc):
+    if not is_str(desc):
         raise_with_traceback(CheckError('desc argument must be a string'))
 
     raise_with_traceback(CheckError('Failure condition: {desc}'.format(desc=desc)))
 
 
 def not_implemented(desc):
-    if not _is_str(desc):
+    if not is_str(desc):
         raise_with_traceback(CheckError('desc argument must be a string'))
 
     raise_with_traceback(NotImplementedCheckError('Not implemented: {desc}'.format(desc=desc)))
@@ -122,6 +122,13 @@ def inst(obj, ttype, desc=None):
     return obj
 
 
+def subclass(obj, superclass, desc=None):
+    if not issubclass(obj, superclass):
+        raise_with_traceback(_type_mismatch_error(obj, superclass, desc))
+
+    return obj
+
+
 def is_callable(obj, desc=None):
     if not callable(obj):
         if desc:
@@ -225,18 +232,30 @@ def float_param(obj, param_name):
     return obj
 
 
+def opt_numeric_param(obj, param_name):
+    if obj is not None and not isinstance(obj, (int, float)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (int, float), param_name))
+    return obj
+
+
+def numeric_param(obj, param_name):
+    if not isinstance(obj, (int, float)):
+        raise_with_traceback(_param_type_mismatch_exception(obj, (int, float), param_name))
+    return obj
+
+
 def opt_float_param(obj, param_name):
     if obj is not None and not isinstance(obj, float):
         raise_with_traceback(_param_type_mismatch_exception(obj, float, param_name))
     return obj
 
 
-def _is_str(obj):
+def is_str(obj):
     return isinstance(obj, string_types)
 
 
 def str_param(obj, param_name):
-    if not _is_str(obj):
+    if not is_str(obj):
         raise_with_traceback(_param_type_mismatch_exception(obj, str, param_name))
     return obj
 
@@ -695,7 +714,7 @@ def opt_str_elem(ddict, key):
     value = ddict.get(key)
     if value is None:
         return None
-    if not _is_str(value):
+    if not is_str(value):
         raise_with_traceback(_element_check_error(key, value, ddict, str))
     return value
 
@@ -705,6 +724,6 @@ def str_elem(ddict, key):
     str_param(key, 'key')
 
     value = ddict[key]
-    if not _is_str(value):
+    if not is_str(value):
         raise_with_traceback(_element_check_error(key, value, ddict, str))
     return value
