@@ -9,9 +9,7 @@ class Engine(six.with_metaclass(abc.ABCMeta)):  # pylint: disable=no-init
     def execute(pipeline_context, execution_plan):
         '''Core execution method.
 
-
-
         Args:
             pipeline_context (SystemPipelineExecutionContext): The pipeline execution context.
-            execution_plan ()
+            execution_plan (ExecutionPlan): The plan to execute.
         '''
