@@ -4,7 +4,7 @@ from dagster import check
 from dagster.core.definitions import PartitionSetDefinition, PipelineDefinition, SystemStorageData
 from dagster.core.definitions.pipeline import ExecutionSelector
 from dagster.core.errors import DagsterInvariantViolationError
-from dagster.core.events import DagsterEvent, DagsterEventType
+from dagster.core.events import DagsterEvent
 from dagster.core.execution.context.system import SystemPipelineExecutionContext
 from dagster.core.execution.memoization import validate_retry_memoization
 from dagster.core.execution.plan.plan import ExecutionPlan
@@ -12,10 +12,10 @@ from dagster.core.instance import DagsterInstance
 from dagster.core.storage.pipeline_run import PipelineRun, PipelineRunStatus
 from dagster.core.system_config.objects import EnvironmentConfig
 from dagster.core.utils import make_new_run_id
-from dagster.utils import ensure_gen, merge_dicts
+from dagster.utils import merge_dicts
 
 from .config import IRunConfig, RunConfig
-from .context_creation_pipeline import scoped_pipeline_context
+from .context_creation_pipeline import pipeline_initialization_manager, scoped_pipeline_context
 from .results import PipelineExecutionResult
 
 
@@ -66,14 +66,9 @@ def _pipeline_execution_iterator(pipeline_context, execution_plan, pipeline_run)
     '''A complete execution of a pipeline. Yields pipeline start, success,
     and failure events. Defers to _steps_execution_iterator for step execution.
     '''
-    if (
-        isinstance(pipeline_context, DagsterEvent)
-        and pipeline_context.event_type  # pylint: disable=no-member
-        == DagsterEventType.PIPELINE_INIT_FAILURE
-    ):
-        yield pipeline_context
-        return
-
+    check.inst_param(pipeline_context, 'pipeline_context', SystemPipelineExecutionContext)
+    check.inst_param(execution_plan, 'execution_plan', ExecutionPlan)
+    check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
     yield DagsterEvent.pipeline_start(pipeline_context)
 
     pipeline_success = True
@@ -104,11 +99,17 @@ def execute_run_iterator(pipeline, pipeline_run, instance):
         pipeline, environment_dict=pipeline_run.environment_dict, run_config=pipeline_run
     )
 
-    with scoped_pipeline_context(
-        pipeline, pipeline_run.environment_dict, pipeline_run, instance, execution_plan,
-    ) as pipeline_context:
+    initialization_manager = pipeline_initialization_manager(
+        pipeline, pipeline_run.environment_dict, pipeline_run, instance, execution_plan
+    )
+    for event in initialization_manager.generate_setup_events():
+        yield event
+    pipeline_context = initialization_manager.get_object()
+    if pipeline_context:
         for event in _pipeline_execution_iterator(pipeline_context, execution_plan, pipeline_run):
             yield event
+    for event in initialization_manager.generate_teardown_events():
+        yield event
 
 
 def execute_pipeline_iterator(pipeline, environment_dict=None, run_config=None, instance=None):
@@ -184,34 +185,37 @@ def execute_pipeline(
 
     pipeline_run = _create_run(instance, pipeline, run_config, environment_dict)
 
-    with scoped_pipeline_context(
+    initialization_manager = pipeline_initialization_manager(
         pipeline,
         environment_dict,
         pipeline_run,
         instance,
         execution_plan,
         raise_on_error=raise_on_error,
-    ) as pipeline_context:
-        event_list = list(
+    )
+    event_list = list(initialization_manager.generate_setup_events())
+    pipeline_context = initialization_manager.get_object()
+    if pipeline_context:
+        event_list.extend(
             _pipeline_execution_iterator(pipeline_context, execution_plan, pipeline_run)
         )
-
-        return PipelineExecutionResult(
+    event_list.extend(initialization_manager.generate_teardown_events())
+    return PipelineExecutionResult(
+        pipeline,
+        run_config.run_id,
+        event_list,
+        lambda: scoped_pipeline_context(
             pipeline,
-            run_config.run_id,
-            event_list,
-            lambda: scoped_pipeline_context(
-                pipeline,
-                environment_dict,
-                pipeline_run,
-                instance,
-                execution_plan,
-                system_storage_data=SystemStorageData(
-                    intermediates_manager=pipeline_context.intermediates_manager,
-                    file_manager=pipeline_context.file_manager,
-                ),
+            environment_dict,
+            pipeline_run,
+            instance,
+            execution_plan,
+            system_storage_data=SystemStorageData(
+                intermediates_manager=pipeline_context.intermediates_manager,
+                file_manager=pipeline_context.file_manager,
             ),
-        )
+        ),
+    )
 
 
 def execute_pipeline_with_preset(
@@ -258,19 +262,10 @@ def execute_pipeline_with_preset(
 def _steps_execution_iterator(pipeline_context, execution_plan, pipeline_run):
     '''Iterates over execution of individual steps yielding the associated events.
     '''
-    check.inst_param(
-        pipeline_context, 'pipeline_context', (DagsterEvent, SystemPipelineExecutionContext)
-    )
+    check.inst_param(pipeline_context, 'pipeline_context', SystemPipelineExecutionContext)
     check.inst_param(execution_plan, 'execution_plan', ExecutionPlan)
     check.inst_param(pipeline_run, 'pipeline_run', PipelineRun)
 
-    if (
-        isinstance(pipeline_context, DagsterEvent)
-        # pylint: disable=no-member
-        and pipeline_context.event_type == DagsterEventType.PIPELINE_INIT_FAILURE
-    ):
-        return ensure_gen(pipeline_context)
-
     if execution_plan.previous_run_id:
         validate_retry_memoization(pipeline_context, execution_plan)
 
@@ -283,14 +278,20 @@ def execute_plan_iterator(execution_plan, pipeline_run, environment_dict=None, i
     environment_dict = check.opt_dict_param(environment_dict, 'environment_dict')
     instance = check.inst_param(instance, 'instance', DagsterInstance)
 
-    with scoped_pipeline_context(
+    initialization_manager = pipeline_initialization_manager(
         execution_plan.pipeline_def, environment_dict, pipeline_run, instance, execution_plan
-    ) as pipeline_context:
-        return _steps_execution_iterator(
-            pipeline_context, execution_plan=execution_plan, pipeline_run=pipeline_run
-        )
+    )
+    for event in initialization_manager.generate_setup_events():
+        yield event
 
-    check.failed('Unexpected state, should be unreachable')
+    pipeline_context = initialization_manager.get_object()
+    if pipeline_context:
+        for event in _steps_execution_iterator(
+            pipeline_context, execution_plan=execution_plan, pipeline_run=pipeline_run
+        ):
+            yield event
+    for event in initialization_manager.generate_teardown_events():
+        yield event
 
 
 def execute_plan(execution_plan, instance, pipeline_run, environment_dict=None):
