@@ -33,4 +33,4 @@ def merge_yamls(file_list):
 def load_yaml_from_path(path):
     check.str_param(path, 'path')
     with open(path, 'r') as ff:
-        return yaml.load(ff)
+        return yaml.safe_load(ff)
